package org.example.file.csv;
import java.math.BigDecimal;
import java.util.LinkedList;
import java.util.List;

import org.objectweb.telosys.util.file.CSVFileParser;


/**
 * This class is a handler to process each line of a CVS file
 * 
 * @author L. Guerin
 *
 */
public class CsvToDataSetParser extends CSVFileParser
{
	private LinkedList _rows = new LinkedList();
	
	public CsvToDataSetParser() 
	{
		super("|", "#");
	}
	
    /* (non-Javadoc)
     * @see org.objectweb.telosys.dal.csv.ICSVHandler#start()
     */
    public void start()
    {
        System.out.println("Start : nothing to do");
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.telosys.dal.csv.ICSVHandler#voidLine(int)
     */
    public void voidLine( int no )
    {
        System.out.println("Void ("+no+") : nothing to do");
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.telosys.dal.csv.ICSVHandler#commentLine(int, java.lang.String)
     */
    public void commentLine( int no, String sLine )
    {
        System.out.println("Comment ("+no+") : nothing to do");
    }
    
	@Override
    public void dataLine( int n, String sLine, String fields[] )
    {
    	if ( fields.length < 4 )
    	{
    		System.out.println("Invalid line : at least 4 fields expected, " + fields.length + " field(s) received");
    	}
    	else
    	{
    		
    		String title           = fields[0] ;
    		String authorLastName  = fields[1] ;
    		String authorFirstName = fields[2] ;
    		String price           = fields[3];
    		BigDecimal bdPrice     = new BigDecimal( ( price != null ? price : "0") ) ;
    		
    		Object[] cells = new Object[4];
    		int i = 0 ;
    		cells[i++] = title ;
    		cells[i++] = bdPrice ;
    		cells[i++] = authorLastName ;
    		cells[i++] = authorFirstName ;
    		_rows.add(cells);

//    		DataRow dr = new DataRow(cells.length, cells);
//    		_rows.add(dr);

    		System.out.println("Row " + n + " added : '" + sLine + "'");
    	}
    }

	@Override
    public void end()
    {
        System.out.println("End");
        
    }

	@Override
	public List<?> getResult() {
		return _rows;
	}

}
